<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ms="urn:schemas-microsoft-com:xslt"
    xmlns:dt="urn:schemas-microsoft-com:datatypes"
    xmlns:ent="http://www.purl.org/NET/ENT/1.0/"
    exclude-result-prefixes="xsl">
	<xsl:output method="xml" omit-xml-declaration="yes" indent="yes"/>
	
	<xsl:template match="/">

		<xsl:apply-templates select="rss/channel"/>
		
	</xsl:template>
	<xsl:template match="rss/channel">

		<xsl:apply-templates select="item"/>

	</xsl:template>
	<xsl:template match="item">


		<xsl:variable name="item_link" select="link"/>
		
		<xsl:variable name="item_title" select="title" />
		
		<xsl:variable name="item_title_nc">
			<xsl:call-template name="escape-colon">
				<xsl:with-param name="string" select="$item_title"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="item_title_na">
			<xsl:call-template name="escape-apos">
				<xsl:with-param name="string" select="$item_title_nc"/>
			</xsl:call-template>
		</xsl:variable>

		
		<xsl:variable name="item_desc" select="description"/>
		
		
		<xsl:variable name="item_desc_na">
			<xsl:call-template name="escape-apos">
				<xsl:with-param name="string" select="$item_desc"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="item_date" select="substring(pubDate, 5, 12)"/>
		
		<xsl:variable name="item_author">
			<xsl:apply-templates select="ent:cloud"/>
		</xsl:variable>

		<div class="ArticleTitle">
			<a href="JavaScript:loadFlyout('{$item_title_na}','{$item_link}','{$item_desc_na}','{$item_date}','{$item_author}');">
				<b><xsl:value-of select="title"/></b>
			</a>
			
		</div>
			
		<div class="ArticleAuthor">
			 	<xsl:apply-templates select="ent:cloud"/>
			
		</div>
		

	</xsl:template>
	
	<xsl:template match="ent:cloud">
		<xsl:apply-templates select="ent:topic[@ent:classification='BLOG']"/>
	</xsl:template>
	
	<xsl:template match="ent:topic">
		<xsl:value-of select="."/>
	</xsl:template>
	
	<xsl:template name="escape-apos">
	<xsl:param name="string" />
	<!-- create an $apos variable to make it easier to refer to -->
	<xsl:variable name="apos" select='"&apos;"' />
	<xsl:choose>
		<!-- if the string contains an apostrophe... -->
		<xsl:when test='contains($string, $apos)' >
			<!-- ... give the value before the apostrophe... -->
			<xsl:value-of select="substring-before($string, $apos)" />
			<!-- ... the escaped apostrophe ... -->
			<xsl:text>\'</xsl:text>
			<!-- ... and the result of applying the template to the
					string after the apostrophe -->
			<xsl:call-template name="escape-apos">
				<xsl:with-param name="string"
								select="substring-after($string, $apos)" />
			</xsl:call-template>
		</xsl:when>
		<!-- otherwise... -->
		<xsl:otherwise>
			<!-- ... just give the value of the string -->
			<xsl:value-of select="$string" />
		</xsl:otherwise>
	</xsl:choose>
	</xsl:template>

	<xsl:template name="escape-colon">
	<xsl:param name="string" />
	<!-- create an $apos variable to make it easier to refer to -->
	<xsl:variable name="col" select='":"' />
	<xsl:choose>
		<!-- if the string contains an apostrophe... -->
		<xsl:when test='contains($string, $col)' >
			<!-- ... give the value before the colon... -->
			<xsl:value-of select="substring-before($string, $col)" />
			<!-- ... the escaped colon ... -->
			<xsl:text> -</xsl:text>
			<!-- ... and the result of applying the template to the
					string after the apostrophe -->
			<xsl:call-template name="escape-colon">
				<xsl:with-param name="string"
								select="substring-after($string, $col)" />
			</xsl:call-template>
		</xsl:when>
		<!-- otherwise... -->
		<xsl:otherwise>
			<!-- ... just give the value of the string -->
			<xsl:value-of select="$string" />
		</xsl:otherwise>
	</xsl:choose>
	</xsl:template>
	
</xsl:stylesheet>

